@@ -246,6 +246,25 @@ static int32_t fs_expiretimeparent(struct fsal_export *exp_hdl)
 	return result;
 }
 
+/**
+ * @brief Get the configured readdir modes for parent handle
+ *
+ * @param[in] exp_hdl   Export to query
+ * @return Readdir modes for parent handle
+ */
+static enum fsal_readdir_mode fs_readdir_mode(struct fsal_export *exp_hdl)
+{
+	struct nullfs_fsal_export *exp =
+		container_of(exp_hdl, struct nullfs_fsal_export, export);
+
+	op_ctx->fsal_export = exp->export.sub_export;
+	uint32_t result = exp->export.sub_export->exp_ops.fs_readdir_mode(
+		exp->export.sub_export);
+	op_ctx->fsal_export = &exp->export;
+
+	return result;
+}
+
 /* get_quota
  * return quotas for this export.
  * path could cross a lower mount boundary which could
@@ -391,6 +410,7 @@ void nullfs_export_ops_init(struct export_ops *ops)
 	ops->fs_supported_attrs = fs_supported_attrs;
 	ops->fs_umask = fs_umask;
 	ops->fs_expiretimeparent = fs_expiretimeparent;
+	ops->fs_readdir_mode = fs_readdir_mode;
 	ops->get_quota = get_quota;
 	ops->set_quota = set_quota;
 	ops->alloc_state = nullfs_alloc_state;
