@@ -84,8 +84,7 @@ void _9p_FlushFlushHook(struct _9p_conn *conn, int tag, unsigned long sequence)
 	struct flush_condition fc;
 
 	PTHREAD_MUTEX_lock(&conn->flush_buckets[bucket].flb_lock);
-	glist_for_each(node, &conn->flush_buckets[bucket].list)
-	{
+	glist_for_each(node, &conn->flush_buckets[bucket].list) {
 		hook = glist_entry(node, struct _9p_flush_hook, list);
 		/* Cancel a request that has the right tag
 		 * --AND-- is older than the flush request.
