@@ -46,6 +46,9 @@
 
 static rados_write_op_t grace_op;
 static pthread_mutex_t grace_op_lock;
+bool takeover;
+bool no_cleanup;
+char object_takeover[NI_MAXHOST];
 
 static int rados_ng_put(char *key, char *val, char *object)
 {
@@ -128,43 +131,24 @@ static int rados_ng_init(void)
 	int ret;
 	size_t len;
 	struct gsh_refstr *recov_oid;
-	char host[NI_MAXHOST];
 	rados_write_op_t op;
 
 	PTHREAD_MUTEX_init(&grace_op_lock, NULL);
 
 	RegisterCleanup(&rados_ng_cleanup_element);
 
-	if (nfs_param.core_param.clustered) {
-		ret = snprintf(host, sizeof(host), "node%d", g_nodeid);
-
-		if (unlikely(ret >= sizeof(host))) {
-			LogCrit(COMPONENT_CLIENTID, "node%d too long",
-				g_nodeid);
-			return -ENAMETOOLONG;
-		} else if (unlikely(ret < 0)) {
-			ret = errno;
-			LogCrit(COMPONENT_CLIENTID,
-				"Unexpected return from snprintf %d error %s (%d)",
-				ret, strerror(ret), ret);
-			return ret;
-		}
-	} else {
-		ret = gethostname(host, sizeof(host));
-		if (ret) {
-			LogEvent(COMPONENT_CLIENTID,
-				 "Failed to gethostname: %s (%d)",
-				 strerror(errno), errno);
-			return -errno;
-		}
+	ret = set_nodeid();
+	if (ret < 0) {
+		LogCrit(COMPONENT_CLIENTID, "Failed to set nodeid : %d", ret);
+		return ret;
 	}
 
-	len = strlen(host) + 6 + 1;
+	len = strlen(nodeid) + 6 + 1;
 	recov_oid = gsh_refstr_alloc(len);
 	gsh_refstr_get(recov_oid);
 
 	/* Can't overrun and shouldn't return EOVERFLOW or EINVAL */
-	(void)snprintf(recov_oid->gr_val, len, "%s_recov", host);
+	(void)snprintf(recov_oid->gr_val, len, "%s_recov", nodeid);
 	rcu_set_pointer(&rados_recov_oid, recov_oid);
 
 	ret = rados_kv_connect(&rados_recov_io_ctx, rados_kv_param.userid,
@@ -172,8 +156,8 @@ static int rados_ng_init(void)
 			       rados_kv_param.namespace);
 	if (ret < 0) {
 		gsh_refstr_put(recov_oid);
-		LogEvent(COMPONENT_CLIENTID, "Failed to connect to cluster: %d",
-			 ret);
+		LogCrit(COMPONENT_CLIENTID, "Failed to connect to cluster: %d",
+			ret);
 		return ret;
 	}
 
@@ -183,18 +167,16 @@ static int rados_ng_init(void)
 				     NULL, 0);
 	gsh_refstr_put(recov_oid);
 	if (ret < 0 && ret != -EEXIST) {
-		LogEvent(COMPONENT_CLIENTID, "Failed to create object");
+		LogCrit(COMPONENT_CLIENTID, "Failed to create object");
 		rados_release_write_op(op);
 		rados_kv_shutdown();
 		return ret;
 	}
 	rados_release_write_op(op);
 
-	/* Create new grace_op to spool changes until grace period is done */
-	grace_op = rados_create_write_op();
-	rados_write_op_omap_clear(grace_op);
+	LogEvent(COMPONENT_CLIENTID,
+		 "rados-ng recovery backend initialization complete");
 
-	LogEvent(COMPONENT_CLIENTID, "Rados kv store init done");
 	return 0;
 }
 
@@ -263,7 +245,7 @@ void rados_ng_pop_clid_entry(char *key, char *val, size_t val_len,
 	cl_name = strtok(dupval, "#");
 	if (!cl_name)
 		cl_name = dupval;
-	clid_ent = add_clid_entry(cl_name);
+	clid_ent = add_clid_entry(cl_name, true);
 
 	rfh_names = strtok(NULL, "#");
 	rfh_name = strtok(rfh_names, "#");
@@ -274,9 +256,8 @@ void rados_ng_pop_clid_entry(char *key, char *val, size_t val_len,
 	gsh_free(dupval);
 }
 
-static void
-rados_ng_read_recov_clids_recover(add_clid_entry_hook add_clid_entry,
-				  add_rfh_entry_hook add_rfh_entry)
+static void rados_ng_read_recov_clids_recover(
+	add_clid_entry_hook add_clid_entry, add_rfh_entry_hook add_rfh_entry)
 {
 	int ret;
 	struct gsh_refstr *recov_oid;
@@ -298,19 +279,83 @@ rados_ng_read_recov_clids_recover(add_clid_entry_hook add_clid_entry,
 	}
 }
 
-static void
-rados_ng_read_recov_clids_takeover(nfs_grace_start_t *gsp,
-				   add_clid_entry_hook add_clid_entry,
-				   add_rfh_entry_hook add_rfh_entry)
+static void rados_ng_read_recov_clids_takeover(
+	nfs_grace_start_t *gsp, add_clid_entry_hook add_clid_entry,
+	add_rfh_entry_hook add_rfh_entry)
 {
+	int ret;
+	struct pop_args args = {
+		.add_clid_entry = add_clid_entry,
+		.add_rfh_entry = add_rfh_entry,
+		.old = false,
+		.takeover = true,
+	};
+
 	if (!gsp) {
+		takeover = false;
+		LogDebug(COMPONENT_CLIENTID, "Recovery object in use %s",
+			 rados_recov_oid->gr_val);
 		rados_ng_read_recov_clids_recover(add_clid_entry,
 						  add_rfh_entry);
 		return;
 	}
 
-	LogEvent(COMPONENT_CLIENTID,
-		 "Unable to perform takeover with rados_ng recovery backend.");
+	/* Its takeover activity */
+	switch (gsp->event) {
+	case EVENT_TAKE_IP:
+		ret = snprintf(object_takeover, sizeof(object_takeover),
+			       "%s_recov", gsp->ipaddr);
+		if (unlikely(ret >= sizeof(object_takeover))) {
+			LogCrit(COMPONENT_CLIENTID,
+				"object_takeover too long %s_recov",
+				gsp->ipaddr);
+			no_cleanup = true;
+			return;
+		} else if (unlikely(ret < 0)) {
+			LogCrit(COMPONENT_CLIENTID, "snprintf %d error %s (%d)",
+				ret, strerror(errno), errno);
+			no_cleanup = true;
+			return;
+		}
+		break;
+	case EVENT_TAKE_NODEID:
+		ret = snprintf(object_takeover, sizeof(object_takeover),
+			       "node%d_recov", gsp->nodeid);
+		if (unlikely(ret >= sizeof(object_takeover))) {
+			LogCrit(COMPONENT_CLIENTID,
+				"object_takeover too long node%d_recov",
+				gsp->nodeid);
+			no_cleanup = true;
+			return;
+		} else if (unlikely(ret < 0)) {
+			LogCrit(COMPONENT_CLIENTID, "snprintf %d error %s (%d)",
+				ret, strerror(errno), errno);
+			no_cleanup = true;
+			return;
+		}
+		break;
+	default:
+		LogWarn(COMPONENT_CLIENTID,
+			"Recovery unknown/unsupported event %d", gsp->event);
+		no_cleanup = true;
+		return;
+	}
+
+	takeover = true;
+
+	LogDebug(COMPONENT_CLIENTID, "Recovery object in use %s",
+		 object_takeover);
+
+	ret = rados_kv_traverse(rados_ng_pop_clid_entry, &args,
+				object_takeover);
+	if (ret < 0) {
+		if (gsp->event == EVENT_TAKE_IP)
+			LogWarn(COMPONENT_CLIENTID,
+				"Failed to takeover IP - %s", gsp->ipaddr);
+		else
+			LogWarn(COMPONENT_CLIENTID,
+				"Failed to takeover node - %d", gsp->nodeid);
+	}
 }
 
 static void rados_ng_cleanup_old(void)
@@ -318,14 +363,33 @@ static void rados_ng_cleanup_old(void)
 	int ret;
 	struct gsh_refstr *recov_oid;
 
-	/* Commit pregrace transaction */
+	if (no_cleanup) {
+		LogDebug(COMPONENT_CLIENTID,
+			 "Recovery object was not set properly, no cleanup");
+		no_cleanup = false;
+	}
 	PTHREAD_MUTEX_lock(&grace_op_lock);
-	rcu_read_lock();
-	recov_oid = gsh_refstr_get(rcu_dereference(rados_recov_oid));
-	rcu_read_unlock();
-	ret = rados_write_op_operate(grace_op, rados_recov_io_ctx,
-				     recov_oid->gr_val, NULL, 0);
-	gsh_refstr_put(recov_oid);
+
+	/* Create new grace_op to spool changes until grace period is done */
+	grace_op = rados_create_write_op();
+	rados_write_op_omap_clear(grace_op);
+
+	/* Commit pregrace transaction */
+	if (!takeover) {
+		rcu_read_lock();
+		recov_oid = gsh_refstr_get(rcu_dereference(rados_recov_oid));
+		rcu_read_unlock();
+		LogDebug(COMPONENT_CLIENTID, "Recovery object to be cleaned %s",
+			 recov_oid->gr_val);
+		ret = rados_write_op_operate(grace_op, rados_recov_io_ctx,
+					     recov_oid->gr_val, NULL, 0);
+		gsh_refstr_put(recov_oid);
+	} else {
+		LogDebug(COMPONENT_CLIENTID, "Recovery object to be cleaned %s",
+			 object_takeover);
+		ret = rados_write_op_operate(grace_op, rados_recov_io_ctx,
+					     object_takeover, NULL, 0);
+	}
 	if (ret < 0) {
 		LogEvent(COMPONENT_CLIENTID,
 			 "Failed to commit grace period transactions: %s",
