@@ -903,42 +903,105 @@ bool state_deleg_conflict_impl(struct fsal_obj_handle *obj, bool write)
 		return false;
 
 	struct file_deleg_stats *deleg_stats;
-	struct gsh_client *deleg_client = NULL;
-	open_delegation_type4 deleg_type;
-	bool is_read_deleg;
-	bool is_write_deleg;
+	const uint64_t *current_clientid = NULL;
+	struct glist_head *glist;
+	state_t *state;
+	/* true when current op’s client already holds a delegation */
+	bool same_client_has_deleg = false;
+	/* true when another client holds a WRITE delegation */
+	bool other_client_has_write = false;
+	/* count of delegations that are still active */
+	unsigned int observed_delegations = 0;
 
 	deleg_stats = &obj->state_hdl->file.fdeleg_stats;
-	deleg_type = deleg_stats->fds_deleg_type;
 
-	if (obj->state_hdl->file.write_delegated)
-		deleg_client =
-			obj->state_hdl->file.write_deleg_client->gsh_client;
-
-	/* Check delegation type - handles both standard and
-	 * ATTRS_DELEG types.
+	/* Cache the current request’s clientid if available. We use it
+	 * to decide whether a delegation belongs to the same client or
+	 * a different one.
 	 */
-	is_read_deleg = (deleg_type == OPEN_DELEGATE_READ ||
-			 deleg_type == OPEN_DELEGATE_READ_ATTRS_DELEG);
-	is_write_deleg = (deleg_type == OPEN_DELEGATE_WRITE ||
-			  deleg_type == OPEN_DELEGATE_WRITE_ATTRS_DELEG);
+	if (op_ctx != NULL && op_ctx->clientid != NULL)
+		current_clientid = op_ctx->clientid;
 
-	if (deleg_stats->fds_curr_delegations > 0 &&
-	    ((is_read_deleg && write) ||
-	     (is_write_deleg && deleg_client != op_ctx->client))) {
-		LogDebug(
-			COMPONENT_STATE,
-			"While trying to perform a %s op, found a conflicting %s delegation",
-			write ? "write" : "read",
-			is_write_deleg ? "WRITE" : "READ");
-		if (async_delegrecall(general_fridge, obj) != 0)
-			LogCrit(COMPONENT_STATE,
-				"Failed to start thread to recall delegation from conflicting operation.");
-		return true;
+	/* Scan every delegation state under the file. We consider both
+	 * “granted” and “recall-in-progress” delegations as active
+	 * because they still block conflicting opens until the client
+	 * returns them.
+	 */
+	if (deleg_stats->fds_curr_delegations > 0) {
+		glist_for_each(glist, &obj->state_hdl->file.list_of_states) {
+			state = glist_entry(glist, state_t, state_list);
+
+			if (state->state_type != STATE_TYPE_DELEG)
+				continue;
+
+			if (state->state_data.deleg.sd_state != DELEG_GRANTED &&
+			    state->state_data.deleg.sd_state !=
+				    DELEG_RECALL_WIP)
+				continue;
+
+			nfs_client_id_t *state_client =
+				state->state_owner->so_owner.so_nfs4_owner
+					.so_clientrec;
+			bool same_client = false;
+
+			if (state_client != NULL && current_clientid != NULL &&
+			    state_client->cid_clientid == *current_clientid)
+				same_client = true;
+
+			if (same_client)
+				same_client_has_deleg = true;
+			else if (state->state_data.deleg.sd_type ==
+					 OPEN_DELEGATE_WRITE ||
+				 state->state_data.deleg.sd_type ==
+					 OPEN_DELEGATE_WRITE_ATTRS_DELEG)
+				other_client_has_write = true;
+
+			observed_delegations++;
+		}
 	}
-	return false;
-}
 
+	LogFullDebug(
+		COMPONENT_STATE,
+		"write=%d same_client_has_deleg=%d other_client_has_write=%d total=%u",
+		write, same_client_has_deleg, other_client_has_write,
+		observed_delegations);
+
+	/* No delegations still active so no conflict. */
+	if (observed_delegations == 0)
+		return false;
+
+	/* Write requests: allow the same client to proceed only when
+	 * it is the sole delegate (DELEG23 scenario).
+	 */
+	if (write) {
+		if (observed_delegations == 1 && same_client_has_deleg)
+			return false;
+
+		LogFullDebug(COMPONENT_STATE,
+			     "Write request conflicts with existing delegation");
+		goto recall;
+	}
+
+	/* Read requests conflict only when another client already
+	 * holds a WRITE delegation.
+	 */
+	if (other_client_has_write) {
+		LogFullDebug(
+			COMPONENT_STATE,
+			"Read request conflicts with other client's WRITE delegation");
+		goto recall;
+	}
+
+	/* No conflict detected. */
+	return false;
+
+recall:
+	if (async_delegrecall(general_fridge, obj) != 0)
+		LogCrit(COMPONENT_STATE,
+			"Failed to start thread to recall delegation from conflicting operation.");
+
+	return true;
+}
 /**
  * @brief Acquire st_lock and check if an operation is conflicting
  *        with delegations.
