@@ -278,6 +278,9 @@ static void remove_cache_user(struct cache_user *user)
 	}
 	/* Remove from users fifo queue */
 	TAILQ_REMOVE(&user_fifo_queue, user, queue_entry);
+	idmapper_monitoring__cache_entries_total_set(
+		IDMAPPING_CACHE_ENTITY_USER,
+		(int64_t)avltree_size(&uname_tree));
 	gsh_free(user);
 }
 
@@ -293,6 +296,9 @@ static void remove_cache_group(struct cache_group *group)
 	avltree_remove(&group->gname_node, &gname_tree);
 	/* Remove from groups fifo queue */
 	TAILQ_REMOVE(&group_fifo_queue, group, queue_entry);
+	idmapper_monitoring__cache_entries_total_set(
+		IDMAPPING_CACHE_ENTITY_GROUP,
+		(int64_t)avltree_size(&gname_tree));
 	gsh_free(group);
 }
 
@@ -315,6 +321,8 @@ static void reap_users_cache(void)
 		if (!user_expired(user))
 			break;
 		remove_cache_user(user);
+		idmapper_monitoring__reaped_cache_entity(
+			IDMAPPING_CACHE_ENTITY_USER);
 		user = TAILQ_FIRST(&user_fifo_queue);
 	}
 	PTHREAD_RWLOCK_unlock(&idmapper_user_lock);
@@ -341,6 +349,8 @@ static void reap_groups_cache(void)
 		if (!group_expired(group))
 			break;
 		remove_cache_group(group);
+		idmapper_monitoring__reaped_cache_entity(
+			IDMAPPING_CACHE_ENTITY_GROUP);
 		group = TAILQ_FIRST(&group_fifo_queue);
 	}
 	PTHREAD_RWLOCK_unlock(&idmapper_group_lock);
@@ -495,6 +505,10 @@ add_to_queue:
 		idmapper_monitoring__evicted_cache_entity(
 			IDMAPPING_CACHE_ENTITY_USER, cached_duration);
 	}
+
+	idmapper_monitoring__cache_entries_total_set(
+		IDMAPPING_CACHE_ENTITY_USER,
+		(int64_t)avltree_size(&uname_tree));
 	return true;
 }
 
@@ -573,6 +587,9 @@ bool idmapper_add_group(const struct gsh_buffdesc *name, const gid_t gid)
 		idmapper_monitoring__evicted_cache_entity(
 			IDMAPPING_CACHE_ENTITY_GROUP, cached_duration);
 	}
+	idmapper_monitoring__cache_entries_total_set(
+		IDMAPPING_CACHE_ENTITY_GROUP,
+		(int64_t)avltree_size(&gname_tree));
 	return true;
 }
 
@@ -626,7 +643,10 @@ bool idmapper_lookup_by_uname(const struct gsh_buffdesc *name, uid_t *uid,
 	if (unlikely(gid))
 		*gid = (found_user->gid_set ? &found_user->gid : NULL);
 
-	return user_expired(found_user) ? false : true;
+	const bool is_cache_hit = user_expired(found_user) ? false : true;
+	idmapper_monitoring__cache_usage(IDMAPPING_USERNAME_TO_USER_CACHE,
+					 is_cache_hit);
+	return is_cache_hit;
 }
 
 /**
@@ -677,7 +697,10 @@ bool idmapper_lookup_by_uid(const uid_t uid, const struct gsh_buffdesc **name,
 	if (gid)
 		*gid = (found_user->gid_set ? &found_user->gid : NULL);
 
-	return user_expired(found_user) ? false : true;
+	const bool is_cache_hit = user_expired(found_user) ? false : true;
+	idmapper_monitoring__cache_usage(IDMAPPING_UID_TO_USER_CACHE,
+					 is_cache_hit);
+	return is_cache_hit;
 }
 
 /**
@@ -721,7 +744,10 @@ bool idmapper_lookup_by_gname(const struct gsh_buffdesc *name, uid_t *gid)
 	else
 		LogDebug(COMPONENT_IDMAPPER, "Caller is being weird.");
 
-	return group_expired(found_group) ? false : true;
+	const bool is_cache_hit = group_expired(found_group) ? false : true;
+	idmapper_monitoring__cache_usage(IDMAPPING_GROUPNAME_TO_GROUP_CACHE,
+					 is_cache_hit);
+	return is_cache_hit;
 }
 
 /**
@@ -746,8 +772,9 @@ bool idmapper_lookup_by_gid(const gid_t gid, const struct gsh_buffdesc **name)
 	bool found = false;
 
 	if (likely(found_node)) {
-		found_group = avltree_container_of(
-			found_node, struct cache_group, gid_node);
+		found_group = avltree_container_of(found_node,
+						   struct cache_group,
+						   gid_node);
 		if (found_group->gid == gid)
 			found = true;
 	}
@@ -758,8 +785,9 @@ bool idmapper_lookup_by_gid(const gid_t gid, const struct gsh_buffdesc **name)
 			return false;
 
 		atomic_store_voidptr(cache_slot, found_node);
-		found_group = avltree_container_of(
-			found_node, struct cache_group, gid_node);
+		found_group = avltree_container_of(found_node,
+						   struct cache_group,
+						   gid_node);
 	}
 
 	if (likely(name))
@@ -767,7 +795,10 @@ bool idmapper_lookup_by_gid(const gid_t gid, const struct gsh_buffdesc **name)
 	else
 		LogDebug(COMPONENT_IDMAPPER, "Caller is being weird.");
 
-	return group_expired(found_group) ? false : true;
+	const bool is_cache_hit = group_expired(found_group) ? false : true;
+	idmapper_monitoring__cache_usage(IDMAPPING_GID_TO_GROUP_CACHE,
+					 is_cache_hit);
+	return is_cache_hit;
 }
 
 /**
@@ -835,19 +866,19 @@ void idmapper_destroy_cache(void)
 #ifdef USE_DBUS
 
 /**
- *@brief Dbus method for showing idmapper cache
+ *@brief Dbus method for showing idmapper user cache
  *
  *@param[in]  args
  *@param[out] reply
  */
-static bool show_idmapper(DBusMessageIter *args, DBusMessage *reply,
-			  DBusError *error)
+static bool show_idmapper_users(DBusMessageIter *args, DBusMessage *reply,
+				DBusError *error)
 {
 	struct timespec timestamp;
 	struct avltree_node *node;
 	uint32_t val;
 	DBusMessageIter iter, sub_iter, id_iter;
-	char *namebuff = gsh_malloc(1024);
+	char *namebuff = gsh_malloc(256);
 	dbus_bool_t gid_set;
 
 	dbus_message_iter_init_append(reply, &iter);
@@ -866,13 +897,8 @@ static bool show_idmapper(DBusMessageIter *args, DBusMessage *reply,
 					    uname_node);
 		dbus_message_iter_open_container(&sub_iter, DBUS_TYPE_STRUCT,
 						 NULL, &id_iter);
-		memcpy(namebuff, user->uname.addr, user->uname.len);
-		if (user->uname.len > 255)
-			/*Truncate the name */
-			*(namebuff + 255) = '\0';
-		else
-			*(namebuff + user->uname.len) = '\0';
-
+		snprintf(namebuff, MIN(user->uname.len + 1, 256), "%s",
+			 (char *)user->uname.addr);
 		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_STRING,
 					       &namebuff);
 		val = user->uid;
@@ -898,13 +924,67 @@ static bool show_idmapper(DBusMessageIter *args, DBusMessage *reply,
 	return true;
 }
 
-struct gsh_dbus_method cachemgr_show_idmapper = {
-	.name = "showidmapper",
-	.method = show_idmapper,
+/**
+ *@brief Dbus method for showing idmapper groups cache
+ *
+ *@param[in]  args
+ *@param[out] reply
+ */
+static bool show_idmapper_groups(DBusMessageIter *args, DBusMessage *reply,
+				 DBusError *error)
+{
+	struct timespec timestamp;
+	struct avltree_node *node;
+	uint32_t val;
+	DBusMessageIter iter, sub_iter, id_iter;
+	char *namebuff = gsh_malloc(256);
+
+	dbus_message_iter_init_append(reply, &iter);
+	now(&timestamp);
+	gsh_dbus_append_timestamp(&iter, &timestamp);
+	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY, "(su)",
+					 &sub_iter);
+	PTHREAD_RWLOCK_rdlock(&idmapper_group_lock);
+	/* Traverse idmapper cache */
+	for (node = avltree_first(&gname_tree); node != NULL;
+	     node = avltree_next(node)) {
+		struct cache_group *group;
+
+		group = avltree_container_of(node, struct cache_group,
+					     gname_node);
+		dbus_message_iter_open_container(&sub_iter, DBUS_TYPE_STRUCT,
+						 NULL, &id_iter);
+		snprintf(namebuff, MIN(group->gname.len + 1, 256), "%s",
+			 (char *)group->gname.addr);
+		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_STRING,
+					       &namebuff);
+		val = group->gid;
+		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_UINT32,
+					       &val);
+
+		dbus_message_iter_close_container(&sub_iter, &id_iter);
+	}
+	PTHREAD_RWLOCK_unlock(&idmapper_group_lock);
+	free(namebuff);
+	dbus_message_iter_close_container(&iter, &sub_iter);
+	return true;
+}
+
+struct gsh_dbus_method cachemgr_show_idmapper_users = {
+	.name = "showidmapper_users",
+	.method = show_idmapper_users,
 	.args = { TIMESTAMP_REPLY,
 		  { .name = "ids", .type = "a(subu)", .direction = "out" },
 		  END_ARG_LIST }
 };
+
+struct gsh_dbus_method cachemgr_show_idmapper_groups = {
+	.name = "showidmapper_groups",
+	.method = show_idmapper_groups,
+	.args = { TIMESTAMP_REPLY,
+		  { .name = "ids", .type = "a(su)", .direction = "out" },
+		  END_ARG_LIST }
+};
 #endif
 
 /** @} */
