@@ -637,6 +637,9 @@ static struct config_item version4_params[] = {
 		      nfs_version4_parameter, server_owner),
 	CONF_ITEM_BOOL("Virtual_Server", false, nfs_version4_parameter,
 		       virtual_server),
+	CONF_ITEM_BOOL("Ip_Based_Client_Owner_Separation", false,
+		       nfs_version4_parameter,
+		       ip_based_client_owner_separation),
 	CONF_ITEM_STR("DomainName", 1, MAXPATHLEN, DOMAINNAME_DEFAULT,
 		      nfs_version4_parameter, domainname),
 	CONF_ITEM_PATH("IdmapConf", 1, MAXPATHLEN, IDMAPCONF_DEFAULT,
